function pR=estimateRecoveredLinNew(C, D, R, kdays, N0, N1)
%
% LINEARIZED version with constraint C-R-D>=0 
%
% Estimation of Recovered from Confirmed and Deaths,
% Estimation of case fatality and case recovery rates
% This program does no smoothing.
% If smoothing is required, do it outside. 
%
% Input:
% 
% C, D, R : Confirmed, Deaths, Recovered, same length
% kdays : number of days after which Confirmed 
% are assumed to be Recovered, for k-day rule
% if they do not die in between
% N0, N1 : range of data used
% Data of D between N0-1 and N1 are used
% Data of C between N0-1-kdays and N1-1 are used 
% The linear system has N1-N0+1 equations and kdays unknowns
% 
% Output:
% qopt : survival probability d days after Confirmation
% p : kdays-vector of probabilities p_j to die j days after Confirmation  
% R : estimated Recovered, same length as C and D, 
% new values between N0 and N1 only 
% pR: vector of the form [qopt; p; R]
%
if kdays > N1-N0+1
    tdiffk=[N0 N1 kdays]
    error('Not enough equations in estimateRecoveredLinNew')
end 
% 
dD=zeros(size(D)); % vector for daily deaths
dC=zeros(size(C)); % daily Confirmed
Clen=length(C);
% daily values at day i are stored in i-th position
dD(2:Clen)=D(2:Clen)-D(1:Clen-1); 
dC(2:Clen)=C(2:Clen)-C(1:Clen-1);
% we use deaths data between N0-1 and N1 
rhs=dD(N0:N1); % D_n-D_{n-1}, n from N0 to N1 
CC=zeros(N1-N0+1,kdays); % the matrix for the quadratic form
for j=1:kdays  % use the dC shifts as columns
    CC(:,j)=dC(N0-j:N1-j);  
end
q0=zeros(kdays,1); % starting at zero, and lower bounds
% prepare the constraints
onek=ones(kdays,1);
S=zeros(N1-N0+1,N1-N0+1); % for the summation of differences
for j=1:N1-N0+1
    for i=1:j
        S(j,i)=1;
    end
end
% figure
% mesh(S)
% S
ddC=dC(N0-kdays:N1-kdays); % final column of CC
sig=S*ddC; % for later summation of dR
rho=R(N0-1)*ones(N1-N0+1,1); % thi initial values for the new R
cc=C(N0:N1); % C subset
dd=D(N0:N1); % D subset 
% the matrix for inequalities
% The final row is for the constraint on sum(q)
% The main part is modelling R <=  C-D as follows:
% On the subset from N0 to N1:
% Rnew= S*dRnew+rho, by summation of differences.
% With q being the solution, and pd=1-sum(q):
% dRnew=pd*ddC, as done later after optimization,
% thus the constraint is 
% S*dRnew+rho=pd*S*ddC+rho<=cc-dd or
% -sum(q)*sig <= cc-dd-rho-sig.
% This explains
A=[-repmat(sig,1,kdays); onek'];
b=[-sig-rho+cc-dd; 1];
% figure
% mesh(A)
% [rho rho+sig cc-dd-rho]
% pause
% perform linear least squares
qopt=lsqlin(CC,rhs,A,b,[],[],q0,[]);
pd=1-sum(qopt); % the survival rate
% now calculate daily Recovered
dR=pd*ddC;
% and insert into full R vector
R1=R;
for j=N0:N1
    R1(j)=R1(j-1)+dR(j-N0+1);
end
R1=floor(R1);
pR=[pd; qopt; R1];

